@@ -108,6 +108,7 @@
 #' @param archiveMiniature A logical value denoting whether to archive a miniature of the \code{artifact}.
 #' 
 #' @param repoDir A character denoting an existing directory in which an artifact will be saved.
+#' If set to \code{NULL} (by default), uses the \code{repoDir} specified in \link{setLocalRepo}.
 #' 
 #' @param force A logical value denoting whether to archive \code{artifact} if it was already archived in
 #' a Repository.
@@ -118,7 +119,9 @@
 #' of an stored artifact or should the result be the input artifact (\code{chain = TRUE}), so that chaining code 
 #' can be used. See examples.
 #'
-#' @param silent If TRUE produces no warnings
+#' @param silent If TRUE produces no warnings.
+#' 
+#' @param ascii A logical value. An \code{ascii} argument is passed to \link{save} function.
 #' 
 #' @author 
 #' Marcin Kosinski , \email{m.p.kosinski@@gmail.com}
@@ -249,12 +252,13 @@
 #' @family archivist
 #' @rdname saveToRepo
 #' @export
-saveToRepo <- function( artifact, repoDir, archiveData = TRUE, 
+saveToRepo <- function( artifact, repoDir = NULL, archiveData = TRUE, 
                         archiveTags = TRUE, 
                         archiveMiniature = TRUE, force = TRUE, rememberName = TRUE, 
-                        chain = FALSE, ... , silent=FALSE){
-  stopifnot( is.character( repoDir ), is.logical( c( archiveData, archiveTags, archiveMiniature, 
+                        chain = FALSE, ... , silent=FALSE, ascii = TRUE){
+  stopifnot( is.logical( c( archiveData, archiveTags, archiveMiniature, 
                                                      chain, rememberName ) ) )
+  stopifnot( is.character( repoDir ) | is.null( repoDir ) )
   
   md5hash <- digest( artifact )
   objectName <- deparse( substitute( artifact ) )
@@ -282,12 +286,12 @@ saveToRepo <- function( artifact, repoDir, archiveData = TRUE,
     rememberName = FALSE
   }
   if ( rememberName ){
-    save( file = paste0(repoDir,"gallery/", md5hash, ".rda"), ascii = TRUE, list = objectName,  envir = parent.frame(1))
+    save( file = paste0(repoDir,"gallery/", md5hash, ".rda"), ascii = ascii, list = objectName,  envir = parent.frame(1))
   }else{ 
 #    assign( value = artifact, x = md5hash, envir = .GlobalEnv )
 #    save( file = paste0(repoDir, "gallery/", md5hash, ".rda"),  ascii=TRUE, list = md5hash, envir = .GlobalEnv  )
     assign( value = artifact, x = md5hash, envir = .ArchivistEnv )
-    save( file = paste0(repoDir, "gallery/", md5hash, ".rda"),  ascii=TRUE, list = md5hash, envir = .ArchivistEnv  )
+    save( file = paste0(repoDir, "gallery/", md5hash, ".rda"),  ascii=ascii, list = md5hash, envir = .ArchivistEnv  )
     rm(list = md5hash, envir = .ArchivistEnv)
   }
   
@@ -311,11 +315,11 @@ saveToRepo <- function( artifact, repoDir, archiveData = TRUE,
   # if chaining code is used, the "data" attr is not needed
   if ( archiveData & !chain ){
     attr( md5hash, "data" )  <-  extractData( artifact, parrentMd5hash = md5hash, 
-                                              parentDir = repoDir, isForce = force )
+                                              parentDir = repoDir, isForce = force, ASCII = ascii )
   }
   if ( archiveData & chain ){
     extractData( artifact, parrentMd5hash = md5hash, 
-                 parentDir = repoDir, isForce = force )
+                 parentDir = repoDir, isForce = force, ASCII = ascii )
   }
   
   # whether to archive miniature
